@@ -6,9 +6,11 @@ use warnings;
 use utf8;
 use parent qw/Plack::Component/;
 
-our $VERSION = '0.000_005';
+our $VERSION = '0.000_006';
 
 use DBIx::Simple;
+use Email::Sender::Simple 'sendmail';
+use Email::Simple;
 use File::Slurp;
 use HTML::TreeBuilder;
 use HTML::Element::Library;
@@ -62,6 +64,25 @@ sub make_slug {
 	$slug
 }
 
+sub product_to_schemaorg {
+	my ($include_url, %data) = @_;
+	my $stock = $data{stock} > 0 ? 'InStock' : 'OutOfStock';
+	+{
+		'@context' => 'http://schema.org/',
+		'@type'    => 'Product',
+		name => $data{title},
+		image => "/static/fullpics/$data{product}-1.jpg",
+		description => $data{summary},
+		offers => {
+			'@type' => 'Offer',
+			price => ($data{price} =~ s/(..)$/\.$1/r),
+			priceCurrency => 'GBP',
+			availability => "http://schema.org/$stock",
+			($include_url ? (url => "/details/$data{product}/" . make_slug $data{title}) : ())
+		}
+	}
+}
+
 our %highlight;
 sub form_table_row {
 	my ($data, $tr) = @_;
@@ -189,6 +210,14 @@ sub order_app {
 			}
 			$db{$$}->insert(orders => {id => $id, %parms});
 			$db{$$}->commit;
+			sendmail (Email::Simple->create(
+				header => [
+					From    => $ENV{OOF_EMAIL_FROM},
+					To      => $ENV{OOF_EMAIL_TO},
+					Subject => "Order $id placed",
+				],
+				body => 'A new order was placed.',
+			)) if $ENV{OOF_EMAIL_TO};
 		} catch {
 			$db{$$}->rollback;
 			$err = [500, ['Content-type', 'text/plain'], ["Error: $_"]]
@@ -230,14 +259,15 @@ sub details_app {
 	$db{$$} //= DBIx::Simple->connect($ENV{OOF_DSN} // 'dbi:Pg:');
 	my $tree = $details->clone;
 	my ($id) = $env->{PATH_INFO} =~ m,^/(\d+),;
-	my ($title, $summary) = $db{$$}->select(products => [qw/title summary/], {product => $id})->list;
+	my %data = %{$db{$$}->select(products => '*', {product => $id})->hash};
 	my @pics = <static/fullpics/$id-*>;
-	my $slug = make_slug $title;
-	$tree->find('title')->replace_content("Pictures of $title | ledparts4you");
-	$tree->find('h2')->replace_content($title);
-	$tree->fid('summary')->replace_content($summary);
+	my $slug = make_slug $data{title};
+	$tree->find('title')->replace_content("$data{title} | ledparts4you");
+	$tree->find('h2')->replace_content($data{title});
+	$tree->fid('summary')->replace_content($data{summary});
 	$tree->look_down(rel => 'canonical')->attr(href => "/details/$id/$slug");
 	$tree->fid('pictures')->find('li')->iter3(\@pics, \&details_list_element);
+	$tree->fid('jsonld')->replace_content(encode_json product_to_schemaorg '', %data);
 
 	for my $ahref ($tree->find('a')) {
 		$ahref->attr(href => "/form?highlight=$id") if $ahref->attr('href') eq '/';
